#! /bin/bash
if [[ ! -r ~/.arc/usercert.pem ]] ; then
  if [[ ! -r ~/usercert.p12 ]] ; then
    echo "No installed certs and no exported cert, aborting."
    echo "Please exporet your certificate from Firefox to file ~/usercert.p12 and run again."
    exit 1;
  fi
  echo 'Transforming your certificate (passphrase needed)'
  which globus_cert_importer.sh > /dev/null 2>&1 \
    || echo 'globus-Cert_importer.sh script missing, aborting.' \
    && exit 1
  globus_cert_importer.sh ~/usercert.p12
  -d  /.arc || mkdir -v ~/.arc;
  mv -fv ~/user{cert,key}.pem ~/.arc
  echo ''
fi

echo 'Checking your client workdir and VO definitions...'
if [[ ! -d ~/.arc/vomsdir ]] ; then
 echo 'Missing .arc/vomsdir' 
 mkdir -vp ~/.arc/vomsdir
fi

grep voms.sling.si ~/.arc/vomsdir/voms.sling.si.lsc  > /dev/null 2>&1 \
  || echo -e "/C=SI/O=SiGNET/O=SLING/CN=voms.sling.si\n/C=SI/O=SiGNET/CN=SiGNET CA" > ~/.arc/vomsdir/voms.sling.si.lsc 
 
grep gen.vo.sling.si ~/.arc/vomses  > /dev/null 2>&1 \
 || echo -e '"gen.vo.sling.si" "voms.sling.si" "15001" "/C=SI/O=SiGNET/O=SLING/CN=voms.sling.si" "gen.vo.sling.si"' >> ~/.arc/vomses

grep cipkebip ~/.arc/vomses  > /dev/null 2>&1 \
 || echo -e '"cipkebip" "voms.sling.si" "15002" "/C=SI/O=SiGNET/O=SLING/CN=voms.sling.si" "cipkebip"' >> ~/.arc/vomses

grep hpc.fis.unm.si ~/.arc/vomses  > /dev/null 2>&1 \
 || echo -e '"hpc.fis.unm.si" "voms.sling.si" "15005" "/C=SI/O=SiGNET/O=SLING/CN=voms.sling.si""hpc.fis.unm.si"' >> ~/.arc/vomses
echo 'Ok.'

echo 'Checking your client.conf...'
grep computing/nsc  ~/.arc/client.conf  > /dev/null 2>&1 \
 || cat >> ~/.arc/client.conf << FNORD


[computing/jost] 
url=ldap://jost.arnes.si:2135 
infointerface=org.nordugrid.ldapng 
jobinterface=org.nordugrid.gridftpjob
FNORD

echo 'Ok.'
echo ''

if ! which arcproxy > /dev/null 2>&1 ; then
  echo 'arcproxy not found; please install arc client packages.'
  exit 1
else
  echo 'Arcproxy installed, proceeding.'
fi



echo 'Activating your proxy - this will fail if you have not registered with NSC vo at gen.vo VOMS here: https://voms.sling.si:8443/voms/nsc.ijs.si/register/start.action"'
arcproxy -S hpc.fis.unm.si \
  || echo "arcproxy failed; register and try again." && exit
echo ''

echo 'Preparing for a test job'
cat > test1.xrsl << FNORD
&
(executable = /usr/bin/env)
(jobname = "test1")
(stdout=test.log)
(join=yes)
(gridtime=1000)
(gmlog=log)
(memory=2000)
FNORD
# this is for looking at problems:
#arcsub -c jost.arnes.si -S org.nordugrid.gridftpjob -o joblist.xml test1.xrsl -d DEBUG
# Submitting your test job:
arcsub -c jost.arnes.si -o joblist.xml test1.xrsl
echo 'Perhaps we captured the id in joblist.xml:'
cat joblist.xml
echo 'This is how we test for job status - bit it takes 5 minutes for the infosystem to catch up: arcstat -a'
arcstat -a
echo 'Also look at http://www.sling.si/gridmonitor/loadmon.php'
echo 'Once your job is done, retrieve results with arcget -a'
echo 'Hope it works for you! Bye, -jan'
